@@ -3,11 +3,11 @@
 floating.pie<-function(xpos,ypos,x,edges=200,radius=1,col=NULL,
  startpos=0,shadow=FALSE,shadow.col=c("#ffffff","#cccccc"),...) {
 
- if (!is.numeric(x) || any(is.na(x) | x<=0))
-  stop("floating.pie: x values must be positive.")
- x<-c(0,cumsum(x)/sum(x))
- dx <- diff(x)
- nx <- length(dx)
+ if (!is.numeric(x)) stop("floating.pie: x values must be numeric.")
+ validx<-which(!is.na(x) & x > 0)
+ x<-c(0,cumsum(x[validx])/sum(x[validx]))
+ dx<-diff(x)
+ nx<-length(dx)
  if (is.null(col)) col<-rainbow(nx)
  else if(length(col) < nx) col<-rep(col,nx)
  # scale the y radius
@@ -23,7 +23,7 @@ floating.pie<-function(xpos,ypos,x,edges=200,radius=1,col=NULL,
  }
  for(i in 1:nx) {
   n<-max(2,floor(edges*dx[i]))
-  t2p<-2*pi*seq(x[i],x[i + 1],length=n)+startpos
+  t2p<-2*pi*seq(x[i],x[i+1],length=n)+startpos
   xc<-c(cos(t2p)*radius+xpos,xpos)
   yc<-c(sin(t2p)*yradius+ypos,ypos)
   polygon(xc,yc,col=col[i],...)
